@@ -131,20 +131,18 @@ def get_arguments(parser: ArgumentParser):  # pragma: no cover
     """
     parser.add_argument(
         "--bearer-token",
-        dest="bearer_token",
         env_var="BEARER_TOKEN",
         help="the bearer token for ACRCloud (required)",
         required=True,
     )
     parser.add_argument(
         "--project-id",
-        dest="project_id",
         env_var="PROJECT_ID",
         help="the id of the project at ACRCloud (required)",
         required=True,
     )
     parser.add_argument(
-        "--stream_id",
+        "--stream-id",
         env_var="STREAM_ID",
         help="the id of the stream at ACRCloud (required)",
         required=True,
@@ -175,38 +173,38 @@ def get_arguments(parser: ArgumentParser):  # pragma: no cover
         "--email", env_var="EMAIL", help="send an email", action="store_true"
     )
     parser.add_argument(
-        "--email_from", env_var="EMAIL_FROM", help="the sender of the email"
+        "--email-from", env_var="EMAIL_FROM", help="the sender of the email"
     )
     parser.add_argument(
-        "--email_to", env_var="EMAIL_TO", help="the recipients of the email"
+        "--email-to", env_var="EMAIL_TO", help="the recipients of the email"
     )
     parser.add_argument(
-        "--email_cc", env_var="EMAIL_CC", help="the cc recipients of the email"
+        "--email-cc", env_var="EMAIL_CC", help="the cc recipients of the email"
     )
     parser.add_argument(
-        "--email_bcc", env_var="EMAIL_BCC", help="the bcc recipients of the email"
+        "--email-bcc", env_var="EMAIL_BCC", help="the bcc recipients of the email"
     )
     parser.add_argument(
-        "--email_server",
+        "--email-server",
         env_var="EMAIL_SERVER",
         help="the smtp server to send the mail with",
     )
     parser.add_argument(
-        "--email_login",
+        "--email-login",
         env_var="EMAIL_LOGIN",
         help="the username to logon to the smtp server (default: email_from)",
     )
     parser.add_argument(
-        "--email_pass", env_var="EMAIL_PASS", help="the password for the smtp server"
+        "--email-pass", env_var="EMAIL_PASS", help="the password for the smtp server"
     )
     parser.add_argument(
-        "--email_subject",
+        "--email-subject",
         env_var="EMAIL_SUBJECT",
         help="The subject of the email, placeholders are $station_name, $year and $month",
         default="SUISA Sendemeldung von $station_name für $year-$month",
     )
     parser.add_argument(
-        "--email_text",
+        "--email-text",
         env_var="EMAIL_TEXT",
         help="""
         A template for the Email text, placeholders are $station_name, $month, $year, $previous_year, $responsible_email, and $email_footer.
@@ -216,7 +214,6 @@ def get_arguments(parser: ArgumentParser):  # pragma: no cover
     parser.add_argument(
         "--email-footer",
         env_var="EMAIL_FOOTER",
-        dest="email_footer",
         help="Footer for the Email",
         default="Email generated by <https://github.com/radiorabe/suisa_sendemeldung>",
     )
@@ -224,21 +221,20 @@ def get_arguments(parser: ArgumentParser):  # pragma: no cover
         "--responsible-email",
         env_var="RESPONSIBLE_EMAIL",
         help="Used to hint whom to contact in the emails text.",
-        required=True,
     )
     parser.add_argument(
-        "--start_date",
+        "--start-date",
         env_var="START_DATE",
         help="the start date of the interval in format YYYY-MM-DD (default: 30 days\
                               before end_date)",
     )
     parser.add_argument(
-        "--end_date",
+        "--end-date",
         env_var="END_DATE",
         help="the end date of the interval in format YYYY-MM-DD (default: today)",
     )
     parser.add_argument(
-        "--last_month",
+        "--last-month",
         env_var="LAST_MONTH",
         action="store_true",
         help="download data of whole last month",
